@@ -1004,7 +1004,7 @@ int psubstitute(objinstptr thisinst)
 
 Boolean has_param(genericptr celem)
 {
-   if (IS_LABEL(celem) == LABEL) {
+   if (IS_LABEL(celem)) {
       stringpart *cstr;
       labelptr clab = (labelptr)celem;
       for (cstr = clab->string; cstr != NULL; cstr = cstr->nextpart)
