@@ -255,8 +255,9 @@ void quit(xcWidget w, caddr_t nulldata)
       else
 	 Fprintf(stderr, "Ctrl-C exit:  reload workspace from \"%s\"\n",
 		xobjs.tempfile);
+      free(xobjs.tempfile);
+      xobjs.tempfile = NULL;
    }
-   free(xobjs.tempfile);
 
 #if defined(HAVE_PYTHON)
    /* exit by exiting the Python interpreter, if enabled */
@@ -348,11 +349,14 @@ u_short countchanges(char **promptstr)
 
 /*----------------------------------------------*/
 /* Check for conditions to approve program exit */
+/* Return 0 if prompt "Okay" button ends the	*/
+/* program, 1 if the program should exit	*/
+/* immediately.					*/
 /*----------------------------------------------*/
 
 #ifdef TCL_WRAPPER
 
-void quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
+int quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
    char *promptstr;
    Boolean doprompt = False;
@@ -381,10 +385,12 @@ void quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
       Tcl_Eval(xcinterp, "wm deiconify .query");
       Tcl_Eval(xcinterp, "raise .query");
       free(promptstr);
+      return 0;
    }
    else {
       free(promptstr);
       quit(w, NULL);
+      return 1;
    }
 }
 
